package com.perforce.hws.deployment;

/**
 * Cross-platform driver to configure a new system for service usage.
 */
public final class ConfigureNewSystem {

	/**
	 * Instantiates a new configure new system.
	 */
	private ConfigureNewSystem() {
		
	}
	
    /**
     * The main method, gets a Deployer for the current context
     * and runs configure. Typically the context will be a
     * particular operating system. It is expected that each
     * deployer takes responsibility for file system layouts
     * and other conventions that are particular to its context.
     * 
     * Using this approach makes it much easier to extend support
     * for different contexts in future.
     *
     * @param args the arguments, no valid arguments as yet.
     */
    public static void main(final String[] args) {
        try {
        	new DeployerFactory().getDeployer().configure();
        } catch (Exception e) {
            e.printStackTrace();
            System.exit(1);
        }
    }
}
