package com.perforce.hws.deployment;

import java.io.IOException;

import com.perforce.hws.deployment.deployers.CentOs;
import com.perforce.hws.deployment.deployers.Deployer;
import com.perforce.hws.deployment.deployers.Osx;
import com.perforce.hws.deployment.deployers.Ubuntu;
import com.perforce.hws.deployment.deployers.Windows;

/**
 * A factory for creating Deployer objects that carry out
 * OS specific operations.
 */
public class DeployerFactory implements OsHelpers {

	/**
	 * Gets a deployer for currently supported operating systems:
	 * 
	 * - Linux
	 *   - Ubuntu
	 *   - Centos
	 * - MacOS
	 * - Windows
	 * 
	 * No allowance is made for version or architecture yet.
	 * 
	 * Operating systems not in this list will result in an
	 * IllegalStateException being thrown.
	 *
	 * @return the deployer
	 * @throws IOException Signals that an I/O exception has occurred.
	 * @throws InterruptedException the interrupted exception
	 */
	public Deployer getDeployer() throws IOException, InterruptedException {
		Deployer deployer = null;
		if (isLinux()) {
			if (isUbuntu()) {
				deployer = new Ubuntu();
			} else if (isCentOS()) {
				deployer = new CentOs();
			} else {
	            throw new IllegalStateException("The current operating system is "
	            		+ "not yet supported: " + osName());
			}
		} else if (isOSX()) {
			deployer = new Osx();
		} else if (isWindows()) {
			deployer = new Windows();
		} else {
            throw new IllegalStateException("The current operating system is "
            		+ "not yet supported: " + osName());
        }
		return deployer;
	}
}
