package com.perforce.hws.deployment;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.attribute.UserPrincipal;

/**
 * Methods to make alterations in the user's file system.
 */
public interface FileSystemHelpers {

	/** Class specific logger. */
    Logger LOGGER = LoggerFactory.getLogger(FileSystemHelpers.class);

    /**
     * Set the ownership of the give filepath to the user in the passed Principal.
     * 
     * @param path The file path to be chowned
     * @param userPrincipal The principal object with the new owner id
     * @throws IOException If the owner for the file path cannot be changed
     */
    default void setOwner(final Path path, final UserPrincipal userPrincipal)
    		throws IOException {
        LOGGER.info("Changing ownership of {} to {}", path, userPrincipal.getName());
        Files.setOwner(path, userPrincipal);
    }
    
    /**
     * Ensure directory exists by creating if not present.
     *
     * @param path the path
     * @throws IOException 
     */
    default void ensureDirectoryExists(Path path) throws IOException {
    	LOGGER.info("Ensuring " + path + " exists");
    	Files.createDirectories(path);
    	LOGGER.info("Ensured " + path);
    }
}
