package com.perforce.hws.deployment;

import java.io.File;
import java.io.IOException;
import java.nio.file.FileSystems;
import java.nio.file.FileVisitResult;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.nio.file.SimpleFileVisitor;
import java.nio.file.attribute.BasicFileAttributes;
import java.nio.file.attribute.UserPrincipal;

/**
 * Interface for specific Unix file helper.
 */
public interface UnixFileSystemHelpers extends FileSystemHelpers {
	
	/**
	 * Sets the owner of working dirs.
	 *
	 * @param user the user
	 * @param installDir the install dir
	 * @throws IOException Signals that an I/O exception has occurred.
	 */
	default void setOwnerOfWorkingDirs(
			String user, String installDir) throws IOException {
        // We set ownership of the log, tmp and etc directories to the new user.
        UserPrincipal userPrincipal = FileSystems.getDefault()
                .getUserPrincipalLookupService()
                .lookupPrincipalByName(user);

        // Navigate through the directory tree changing owner and group
        for (String[] location:new String[][]
        		{{"log"}, {"tmp"}, {"etc"}, {"etc", "p4d"}}) {
        	Path fullpath = Paths.get(installDir, location);
        	// Make sure the directory path exists
        	new File(fullpath.toString()).mkdirs();
        	// Now make them owned by the configured hws user
        	Files.walkFileTree(Paths.get(installDir, location),
        			new SimpleFileVisitor<Path>() {

				@Override
				public FileVisitResult visitFile(final Path file,
						final BasicFileAttributes attrs)
						throws IOException {
					setOwner(file, userPrincipal);
					return FileVisitResult.CONTINUE;
				}
        	});
        }
    }
}
