package com.perforce.hws.deployment.deployers;

import java.io.IOException;
import java.util.Arrays;

/**
 * Class to handle Centos specific install and uninstall operations.
 */
public class CentOs extends Linux {

    /* (non-Javadoc)
     * @see com.perforce.hws.deployment.deployers.Linux#configure()
     */
    @Override
    public void configure() throws InterruptedException, IOException {
        super.configure();
        execOutOrFail("chkconfig", "--add", "helix-ws");
        execOutOrFail("chkconfig", "--level", "2345", "helix-ws", "on");
    }

    /* (non-Javadoc)
     * @see com.perforce.hws.deployment.deployers.Linux#uninstall()
     */
    @Override
    public void uninstall(final boolean inInstaller)
    		throws IOException, InterruptedException {
        super.uninstall(inInstaller);

        boolean isRegistered;
        try {
            String options = execOutOrFail("chkconfig", "--list", "helix-ws");
            isRegistered = options.contains("helix-ws");
        } catch (Exception e) {
            isRegistered = false;
        }

        if (isRegistered) {
            execOrFail("chkconfig", "--del", "helix-ws");
        }
    }

    /* (non-Javadoc)
     * @see com.perforce.hws.deployment.deployers.Linux#uninstallPackage()
     */
    @Override
    protected void uninstallPackage() throws IOException, InterruptedException {
        execOrFail("rpm", "-e", "helix-web-services");
    }

    /* (non-Javadoc)
     * @see com.perforce.hws.deployment.deployers.Deployer#postUninstall()
     */
    @Override
    public void postUninstall() throws IOException {
        rmtree(getInstallDir());
    }

	@Override
	protected boolean isPackageInstalled() throws IOException, InterruptedException {
        try {
            String allPackages = execOutOrFail("rpm", "-qa");
            return Arrays.stream(allPackages.split("\n"))
                    .anyMatch(s -> s.contains("helix-web-services"));
        } catch (IOException | IllegalStateException e) {
            return false;
        } catch (InterruptedException e) {
            throw new IllegalStateException(e);
        }
	}
}
