package com.perforce.hws.deployment.deployers;

import java.io.IOException;

/**
 * Interface for all deployers that handle install/uninstall
 * tp implement.
 */
public interface IDeployer {

    /**
     * Configures HWS once it has installed.
     *
     * @throws InterruptedException the interrupted exception
     * @throws IOException          Signals that an I/O exception has occurred.
     */
    void configure() throws InterruptedException, IOException;

    /**
     * Uninstalls HWS.
     *
     * @param inInstaller If true, this is being executed by a package or installer
     * @throws IOException          Signals that an I/O exception has occurred.
     * @throws InterruptedException the interrupted exception
     */
    void uninstall(boolean inInstaller) throws IOException, InterruptedException;

    /**
     * Carries out any post uninstall operations.
     *
     * @throws IOException Signals that an I/O exception has occurred.
     */
    void postUninstall() throws IOException;
    
    /**
     * Ensure that the paths we are going to use during configuration are present.
     * @throws IOException Signals that an I/O exception has occurred.
     */
    void ensureDirectories() throws IOException;
}
