package com.perforce.hws.deployment.deployers;

import java.io.IOException;
import java.nio.file.Files;

/**
 * Deployer operations specific to Linux based systems.
 */
public abstract class Linux extends Unix {

    /* (non-Javadoc)
     * @see com.perforce.hws.deployment.deployers.Deployer#configure()
     */
    @Override
    public void configure() throws InterruptedException, IOException {
    	ensureDirectories();
        if (!userExistsViaGetent(unixUsername())) {
            createLinuxUser(unixUsername(), getInstallDir());
        }

        setOwnerOfWorkingDirs(unixUsername(), getInstallDir());

        // Register init.d service
        if (!Files.exists(initDPath())) {
            Files.createSymbolicLink(initDPath(), sbinPath());
        }
        createTrustFiles();
        // Create /opt/perforce/helix-web-services/etc/example
        createExampleConfig();
        reconfigureUnixDefaults();
    }
    
	/* (non-Javadoc)
     * @see com.perforce.hws.deployment.deployers.Deployer#uninstall()
     */
    @Override
    public void uninstall(final boolean inInstaller)
    		throws IOException, InterruptedException {
        try {
            if (isServiceRunningOnLinux()) {
                execOrFail("service", "helix-ws", "stop");
            }
        } catch (IllegalStateException s) {
        }
        if (Files.exists(initDPath())) {
            Files.delete(initDPath());
        }

        if (isPackageInstalled() && !inInstaller) {
            uninstallPackage();
        }
    }

    /**
     * Checks if is service running on linux.
     *
     * @return true, if is service running on linux
     */
    protected boolean isServiceRunningOnLinux() {
        try {
            String status = execOutOrFail("service", "helix-ws", "status");
            return status.contains("running");
        } catch (InterruptedException | IOException e) {
            return false;
        }
    }

    /**
     * Uninstall package.
     *
     * @throws IOException          Signals that an I/O exception has occurred.
     * @throws InterruptedException the interrupted exception
     */
    protected abstract void uninstallPackage()
            throws IOException, InterruptedException;

    /**
     * Checks if is package installed.
     *
     * @return true, if is package installed
     * @throws IOException          Signals that an I/O exception has occurred.
     * @throws InterruptedException the interrupted exception
     */
    protected abstract boolean isPackageInstalled()
    		throws IOException, InterruptedException;
}
