package com.perforce.hws.deployment.deployers;

import java.io.IOException;
import java.nio.file.Files;

/**
 * Deployer for operations specific to Osx.
 */
public class Osx extends Unix {

    /* (non-Javadoc)
     * @see com.perforce.hws.deployment.deployers.Deployer#configure()
     */
    @Override
    public void configure() throws InterruptedException, IOException {
    	ensureDirectories();
        if (!userExistsViaDscl(unixUsername())) {
            createUserWithDscl(unixUsername(), getInstallDir());
        }

        setOwnerOfWorkingDirs(unixUsername(), getInstallDir());

        // Register launchd service
        String launchdConfig = new String(readAll(getClass()
                .getResourceAsStream("/" + plistPath().getFileName())));
        launchdConfig = launchdConfig.replace("{install_dir}", getInstallDir());
        Files.write(plistPath(), launchdConfig.getBytes());

        createTrustFiles();
        
        // Create /opt/perforce/helix-web-services/etc/example
        createExampleConfig();

        reconfigureUnixDefaults();

    }

    /* (non-Javadoc)
     * @see com.perforce.hws.deployment.deployers.Deployer#uninstall()
     */
    @Override
    public void uninstall(final boolean inInstaller)
    		throws IOException, InterruptedException {
        if (Files.exists(plistPath())) {
            execOrFail("launchctl", "unload", "-w",
                    plistPath().toAbsolutePath().toString());
            Files.delete(plistPath());
        }
    }

    /* (non-Javadoc)
     * @see com.perforce.hws.deployment.deployers.Deployer#postUninstall()
     */
    @Override
    public void postUninstall() throws IOException {
        rmtree(getInstallDir(), p -> !p.startsWith(p4ConfigDirPath()));
    }
}
