package com.perforce.hws.deployment.deployers;

import java.io.IOException;
import java.util.Arrays;

/**
 * Deployer specifically for Ubuntu..
 */
public class Ubuntu extends Linux {

    /* (non-Javadoc)
     * @see com.perforce.hws.deployment.deployers.Linux#configure()
     */
    @Override
    public void configure() throws InterruptedException, IOException {
        super.configure();
        execOrFail("update-rc.d", "helix-ws", "defaults");
    }

    /* (non-Javadoc)
     * @see com.perforce.hws.deployment.deployers.Linux#uninstall()
     */
    @Override
    public void uninstall(final boolean inInstaller)
    		throws IOException, InterruptedException {
        super.uninstall(inInstaller);
        execOrFail("update-rc.d", "helix-ws", "remove");
    }

    /* (non-Javadoc)
     * @see com.perforce.hws.deployment.deployers.Linux#uninstallPackage()
     */
    @Override
    protected void uninstallPackage() throws IOException, InterruptedException {
        execOrFail("dpkg", "-r", "helix-web-services");
    }

    /* (non-Javadoc)
     * @see com.perforce.hws.deployment.deployers.Deployer#postUninstall()
     */
    @Override
    public void postUninstall() throws IOException {
        // No actions for post uninstall, we don't want
        // to rmtree here
    }

	@Override
	protected boolean isPackageInstalled() throws IOException, InterruptedException {
	    String out = execOutOrFail("dpkg", "-l");
	    return Arrays.stream(out.split("\n"))
	            .map(line -> line.split("\\s+"))
	            .filter(parts -> parts.length > 1)
	            .map(parts -> parts[1])
	            .anyMatch(s -> s.contains("helix-web-services"));
	}
}
