package com.perforce.hws.deployment.deployers;

import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.StandardOpenOption;
import java.util.stream.Collectors;

import com.perforce.hws.deployment.UnixFileSystemHelpers;

/**
 * Deployer for Unix based systems.
 */
public abstract class Unix extends Deployer implements UnixFileSystemHelpers {
	
	/**
	 * Reconfigure unix defaults.
	 * @throws IOException Signals that an I/O exception has occurred.
	 * @throws InterruptedException the interrupted exception
	 */
	protected void reconfigureUnixDefaults()
			throws IOException, InterruptedException {
        if (configHasNoEdits()) {
            int uid = Integer.valueOf(execOutOrFail(
            		"id", "-u", unixUsername()).trim());
            int gid = Integer.valueOf(execOutOrFail(
            		"id", "-g", unixUsername()).trim());
            String converted = Files.lines(configPath())
                    .map(l -> {
                        if (l.contains("NOEDITS")) {
                            return "";
                        } else if (l.contains("# HWS_PORT: 9000")) {
                            return "HWS_PORT: 443";
                        } else if (l.contains("# ENABLE_HTTPS: false")) {
                            return "ENABLE_HTTPS: true";
                        } else if (l.contains("# KEYSTORE_FILE:")) {
                            return "KEYSTORE_FILE: " + keystorePath()
                            	.toAbsolutePath().toString();
                        } else if (l.contains("# KEYSTORE_PASSWORD:")) {
                            return "KEYSTORE_PASSWORD: changeit";
                        } else if (l.contains("# TRUSTSTORE_FILE:")) {
                            return "TRUSTSTORE_FILE: " + truststorePath()
                            	.toAbsolutePath().toString();
                        } else if (l.contains("# TRUSTSTORE_PASSWORD:")) {
                            return "TRUSTSTORE_PASSWORD: changeit";
                        } else if (l.contains("# SETUID: 0")) {
                            return "SETUID: " + uid;
                        } else if (l.contains("# SETGID: 0")) {
                            return "SETGID: " + gid;
                        } else if (l.contains("# JWT_SIGNING_KEY:")) {
                            return "JWT_SIGNING_KEY: " + createJWTSigningKey();
                        } else if (l.contains("# P4DCONFIGDIR:")) {
                            return "P4DCONFIGDIR: " + p4ConfigDirPath()
                            	.toAbsolutePath().toString();
                        } else {
                            return l;
                        }
                    })
                    .collect(Collectors.joining("\n"));
            Files.write(configPath(), converted.getBytes(),
            		StandardOpenOption.TRUNCATE_EXISTING);
        }
    }

	/* (non-Javadoc)
	 * @see com.perforce.hws.deployment.deployers.Deployer#ensurePaths()
	 */
	@Override
	public void ensureDirectories() throws IOException {
		super.ensureDirectories();
		ensureDirectoryExists(logDirectory());
		ensureDirectoryExists(tmpDirectory());
	}
}
